@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# encoding: utf-8
 import os
 import elementary
 import edje
@@ -6,10 +7,16 @@ import ecore
 import evas
 
 #----- Layout -{{{-
-def layout_clicked(obj, it):
+def _event(*args, **kargs):
+    print((args, kargs))
+
+def layout_clicked(obj):
     win = elementary.Window("layout", elementary.ELM_WIN_BASIC)
     win.title_set("Layout")
+    win.elm_event_callback_add(_event)
     win.autodel_set(True)
+    if obj is None:
+        win.callback_delete_request_add(lambda o: elementary.exit())
 
     bg = elementary.Background(win)
     win.resize_object_add(bg)
@@ -23,18 +30,20 @@ def layout_clicked(obj, it):
     ly.show()
 
     bt = elementary.Button(win)
-    bt.label_set("Button 1")
-    ly.content_set("element1", bt)
+    bt.text_set("Button 1")
+    ly.part_content_set("element1", bt)
+    bt.elm_event_callback_add(_event)
+    bt.elm_event_callback_del(_event)
     bt.show()
 
     bt = elementary.Button(win)
-    bt.label_set("Button 2")
-    ly.content_set("element2", bt)
+    bt.text_set("Button 2")
+    ly.part_content_set("element2", bt)
     bt.show()
 
     bt = elementary.Button(win)
-    bt.label_set("Button 3")
-    ly.content_set("element3", bt)
+    bt.text_set("Button 3")
+    ly.part_content_set("element3", bt)
     bt.show()
 
     win.show()
@@ -44,7 +53,7 @@ def layout_clicked(obj, it):
 if __name__ == "__main__":
     elementary.init()
 
-    layout_clicked(None, None)
+    layout_clicked(None)
 
     elementary.run()
     elementary.shutdown()
