@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# encoding: utf-8
 import os
 import elementary
 import edje
@@ -6,10 +7,12 @@ import ecore
 import evas
 
 #----- Panel -{{{-
-def panel_clicked(obj, it):
+def panel_clicked(obj):
     win = elementary.Window("panel", elementary.ELM_WIN_BASIC)
     win.title_set("Panel test")
     win.autodel_set(True)
+    if obj is None:
+        win.callback_delete_request_add(lambda o: elementary.exit())
 
     bg = elementary.Background(win)
     win.resize_object_add(bg)
@@ -27,7 +30,7 @@ def panel_clicked(obj, it):
     panel.size_hint_align_set(0.0, evas.EVAS_HINT_FILL);
 
     bt = elementary.Button(win)
-    bt.label_set("HIDE ME :)")
+    bt.text_set("HIDE ME :)")
     bt.size_hint_weight_set(evas.EVAS_HINT_EXPAND, evas.EVAS_HINT_EXPAND);
     bt.size_hint_align_set(evas.EVAS_HINT_FILL, evas.EVAS_HINT_FILL);
     bt.show()
@@ -45,7 +48,7 @@ def panel_clicked(obj, it):
 if __name__ == "__main__":
     elementary.init()
 
-    panel_clicked(None, None)
+    panel_clicked(None)
 
     elementary.run()
     elementary.shutdown()
